pub struct DragEndArgs {
pub timestamp: DInstant,
pub target: InteractionPath,
pub applied: DragDropEffect,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for DRAG_END_EVENT.
Fields
timestamp: DInstantInstant the event happened.
target: InteractionPathDraggable widget that was dragging.
applied: DragDropEffectEffect applied by the drop target on the data.
Is empty or a single flag.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl DragEndArgs
impl DragEndArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
target: impl Into<InteractionPath>,
applied: impl Into<DragDropEffect>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, target: impl Into<InteractionPath>, applied: impl Into<DragDropEffect>, ) -> Self
Sourcepub fn try_new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
target: impl Into<InteractionPath>,
applied: impl Into<DragDropEffect>,
) -> Result<Self, Txt>
pub fn try_new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, target: impl Into<InteractionPath>, applied: impl Into<DragDropEffect>, ) -> Result<Self, Txt>
New args from values that convert into the argument types.
Returns an error if the constructed arguments are invalid.
Sourcepub fn now(
target: impl Into<InteractionPath>,
applied: impl Into<DragDropEffect>,
) -> Self
pub fn now( target: impl Into<InteractionPath>, applied: impl Into<DragDropEffect>, ) -> Self
Sourcepub fn try_now(
target: impl Into<InteractionPath>,
applied: impl Into<DragDropEffect>,
) -> Result<Self, Txt>
pub fn try_now( target: impl Into<InteractionPath>, applied: impl Into<DragDropEffect>, ) -> Result<Self, Txt>
Arguments for event that happened now (INSTANT.now).
Returns an error if the constructed arguments are invalid.
Sourcepub fn validate(&self) -> Result<(), Txt>
pub fn validate(&self) -> Result<(), Txt>
The applied field can only be empty or only have a single flag set.
Sourcepub fn assert_valid(&self)
pub fn assert_valid(&self)
Panics if the arguments are invalid.
Sourceimpl DragEndArgs
impl DragEndArgs
Sourcepub fn was_dropped(&self) -> bool
pub fn was_dropped(&self) -> bool
Data was dropped on a valid target.
Sourcepub fn was_canceled(&self) -> bool
pub fn was_canceled(&self) -> bool
Stopped dragging without dropping on a valid drop target.