DragHoveredArgs

Struct DragHoveredArgs 

pub struct DragHoveredArgs {
    pub timestamp: DInstant,
    pub prev_target: Option<InteractionPath>,
    pub target: Option<InteractionPath>,
    pub position: DipPoint,
    pub hits: HitTestInfo,
    pub propagation: EventPropagationHandle,
}
Arguments for DRAG_HOVERED_EVENT.

Fields

timestamp: DInstant

Instant the event happened.

prev_target: Option<InteractionPath>

Previous hovered target.

target: Option<InteractionPath>

New hovered target.

position: DipPoint

Position of the cursor in the window’s content area.

hits: HitTestInfo

Hit-test result for the cursor point in the window.

propagation: EventPropagationHandle

Propagation handle associated with this event instance.

Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.

Implementations

Source

impl DragHoveredArgs

pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, prev_target: impl Into<Option<InteractionPath>>, target: impl Into<Option<InteractionPath>>, position: impl Into<DipPoint>, hits: impl Into<HitTestInfo>, ) -> Self

New args from values that convert into the argument types.

pub fn now( prev_target: impl Into<Option<InteractionPath>>, target: impl Into<Option<InteractionPath>>, position: impl Into<DipPoint>, hits: impl Into<HitTestInfo>, ) -> Self

Arguments for event that happened now (INSTANT.now).

Source

impl DragHoveredArgs

pub fn data(&self) -> Var<Vec<DragDropData>>

pub fn is_drag_enter(&self, wgt: WidgetId) -> bool

Returns true if the wgt was not hovered, but now is.

pub fn is_drag_leave(&self, wgt: WidgetId) -> bool

Returns true if the wgt was hovered, but now isn’t.

pub fn was_over(&self, wgt: WidgetId) -> bool

Returns true if the wgt is in prev_target.

pub fn is_over(&self, wgt: WidgetId) -> bool

Returns true if the wgt is in target.

pub fn was_enabled(&self, widget_id: WidgetId) -> bool

Returns true if the widget was enabled in prev_target.

pub fn was_disabled(&self, widget_id: WidgetId) -> bool

Returns true if the widget was disabled in prev_target.

pub fn is_enabled(&self, widget_id: WidgetId) -> bool

Returns true if the widget is enabled in target.

pub fn is_disabled(&self, widget_id: WidgetId) -> bool

Returns true if the widget is disabled in target.

pub fn is_drag_enter_enabled(&self, wgt: WidgetId) -> bool

Returns true if the wgt was not hovered or was disabled, but now is hovered and enabled.

pub fn is_drag_leave_enabled(&self, wgt: WidgetId) -> bool

Returns true if the wgt was hovered and enabled, but now is not hovered or is disabled.

pub fn is_drag_enter_disabled(&self, wgt: WidgetId) -> bool

Returns true if the wgt was not hovered or was enabled, but now is hovered and disabled.

pub fn is_drag_leave_disabled(&self, wgt: WidgetId) -> bool

Returns true if the wgt was hovered and disabled, but now is not hovered or is enabled.