pub struct DragMoveArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub coalesced_pos: Vec<DipPoint>,
pub position: DipPoint,
pub hits: HitTestInfo,
pub target: InteractionPath,
pub propagation: EventPropagationHandle,
}Expand description
DRAG_MOVE_EVENT arguments.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdId of window that received the event.
coalesced_pos: Vec<DipPoint>Positions of the cursor in between the previous event and this one.
Drag move events can be coalesced, i.e. multiple moves packed into a single event.
position: DipPointPosition of the cursor in the window’s content area.
hits: HitTestInfoHit-test result for the cursor point in the window.
target: InteractionPathFull path to the top-most hit in hits.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl DragMoveArgs
impl DragMoveArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
window_id: impl Into<WindowId>,
coalesced_pos: impl Into<Vec<DipPoint>>,
position: impl Into<DipPoint>,
hits: impl Into<HitTestInfo>,
target: impl Into<InteractionPath>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, window_id: impl Into<WindowId>, coalesced_pos: impl Into<Vec<DipPoint>>, position: impl Into<DipPoint>, hits: impl Into<HitTestInfo>, target: impl Into<InteractionPath>, ) -> Self
New args from values that convert into the argument types.