FocusTarget

Enum FocusTarget 

pub enum FocusTarget {
Show 13 variants Direct { target: WidgetId, }, DirectOrExit { target: WidgetId, navigation_origin: bool, }, DirectOrEnter { target: WidgetId, navigation_origin: bool, }, DirectOrRelated { target: WidgetId, navigation_origin: bool, }, Enter, Exit { recursive_alt: bool, }, Next, Prev, Up, Right, Down, Left, Alt,
}
Focus request target.

Variants



Direct

Move focus to widget.

Fields

target: WidgetId

Focusable widget.



DirectOrExit

Move focus to the widget if it is focusable or to the first focusable ancestor.

Fields

target: WidgetId

Maybe focusable widget.

navigation_origin: bool

If true the target always becomes the navigation_origin, even when it is not focusable.



DirectOrEnter

Move focus to the widget if it is focusable or to first focusable descendant.

Fields

target: WidgetId

Maybe focusable widget.

navigation_origin: bool

If true the target becomes the navigation_origin when it is not focusable and has no focusable descendant.



DirectOrRelated

Move focus to the widget if it is focusable, or to the first focusable descendant or to the first focusable ancestor.

Fields

target: WidgetId

Maybe focusable widget.

navigation_origin: bool

If true the target becomes the navigation_origin when it is not focusable and has no focusable descendant.



Enter

Move focus to the first focusable descendant of the current focus.



Exit

Move focus to the first focusable ancestor of the current focus, or the return focus from ALT scopes.

Fields

recursive_alt: bool

If exiting from an ALT scope recursively seek the return widget that is not inside any ALT scope.



Next

Move focus to next from current in scope.



Prev

Move focus to previous from current in scope.



Up

Move focus above current.



Right

Move focus to the right of current.



Down

Move focus bellow current.



Left

Move focus to the left of current.



Alt

Move focus to the current widget ALT scope or out of it.