pub struct ShortcutArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub device_id: Option<InputDeviceId>,
pub shortcut: Shortcut,
pub repeat_count: u32,
pub actions: ShortcutActions,
pub propagation: EventPropagationHandle,
}Expand description
SHORTCUT_EVENT arguments.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdId of window that received the event.
device_id: Option<InputDeviceId>Id of device that generated the event.
Is None if the event was generated programmatically.
shortcut: ShortcutThe shortcut.
repeat_count: u32Number of repeats generated by holding the key pressed.
This is zero for the first key press, increments by one for each event while the key is held pressed.
actions: ShortcutActionsActions that will run if this event propagation is not stopped.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl ShortcutArgs
impl ShortcutArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
window_id: impl Into<WindowId>,
device_id: impl Into<Option<InputDeviceId>>,
shortcut: impl Into<Shortcut>,
repeat_count: impl Into<u32>,
actions: impl Into<ShortcutActions>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, window_id: impl Into<WindowId>, device_id: impl Into<Option<InputDeviceId>>, shortcut: impl Into<Shortcut>, repeat_count: impl Into<u32>, actions: impl Into<ShortcutActions>, ) -> Self
New args from values that convert into the argument types.