MouseHoverArgs

Struct MouseHoverArgs 

pub struct MouseHoverArgs {
    pub timestamp: DInstant,
    pub window_id: WindowId,
    pub device_id: Option<InputDeviceId>,
    pub position: DipPoint,
    pub hits: HitTestInfo,
    pub prev_target: Option<InteractionPath>,
    pub target: Option<InteractionPath>,
    pub prev_capture: Option<CaptureInfo>,
    pub capture: Option<CaptureInfo>,
    pub propagation: EventPropagationHandle,
}
Fields

timestamp: DInstant

Instant the event happened.

window_id: WindowId

Id of window that received the event.

device_id: Option<InputDeviceId>

Id of device that generated the event.

position: DipPoint

Position of the mouse in the window.

hits: HitTestInfo

Hit-test result for the mouse point in the window.

prev_target: Option<InteractionPath>

Previous top-most hit before the mouse moved.

target: Option<InteractionPath>

Full path to the top-most hit in hits.

Is None when the mouse moves out of a window or the window closes under the mouse and there was a previous hovered widget.

prev_capture: Option<CaptureInfo>

Previous pointer capture.

capture: Option<CaptureInfo>

Current pointer capture.

propagation: EventPropagationHandle

Propagation handle associated with this event instance.

Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.

Implementations

Source

impl MouseHoverArgs

pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, window_id: impl Into<WindowId>, device_id: impl Into<Option<InputDeviceId>>, position: impl Into<DipPoint>, hits: impl Into<HitTestInfo>, prev_target: impl Into<Option<InteractionPath>>, target: impl Into<Option<InteractionPath>>, prev_capture: impl Into<Option<CaptureInfo>>, capture: impl Into<Option<CaptureInfo>>, ) -> Self

New args from values that convert into the argument types.

pub fn now( window_id: impl Into<WindowId>, device_id: impl Into<Option<InputDeviceId>>, position: impl Into<DipPoint>, hits: impl Into<HitTestInfo>, prev_target: impl Into<Option<InteractionPath>>, target: impl Into<Option<InteractionPath>>, prev_capture: impl Into<Option<CaptureInfo>>, capture: impl Into<Option<CaptureInfo>>, ) -> Self

Arguments for event that happened now (INSTANT.now).

Source

impl MouseHoverArgs

pub fn capture_allows(&self, wgt: (WindowId, WidgetId)) -> bool

If capture is None or allows the wgt to receive this event.

pub fn is_mouse_move(&self) -> bool

Event caused by the mouse position moving over/out of the widget bounds.

pub fn is_widget_move(&self) -> bool

Event caused by the widget moving under/out of the mouse position.

pub fn is_capture_change(&self) -> bool

Event caused by a pointer capture change.

pub fn is_mouse_enter(&self, wgt: (WindowId, WidgetId)) -> bool

Returns true if the wgt was not hovered, but now is.

pub fn is_mouse_leave(&self, wgt: (WindowId, WidgetId)) -> bool

Returns true if the wgt was hovered, but now isn’t.

pub fn is_mouse_enter_enabled(&self, wgt: (WindowId, WidgetId)) -> bool

Returns true if the wgt was not hovered or was disabled, but now is hovered and enabled.

pub fn is_mouse_leave_enabled(&self, wgt: (WindowId, WidgetId)) -> bool

Returns true if the wgt was hovered and enabled, but now is not hovered or is disabled.

pub fn is_mouse_enter_disabled(&self, wgt: (WindowId, WidgetId)) -> bool

Returns true if the wgt was not hovered or was enabled, but now is hovered and disabled.

pub fn is_mouse_leave_disabled(&self, wgt: (WindowId, WidgetId)) -> bool

Returns true if the wgt was hovered and disabled, but now is not hovered or is enabled.

pub fn was_over(&self, wgt: (WindowId, WidgetId)) -> bool

Returns true if the wgt is in prev_target and is allowed by the prev_capture.

pub fn is_over(&self, wgt: (WindowId, WidgetId)) -> bool

Returns true if the wgt is in target and is allowed by the current capture.

pub fn was_enabled(&self, widget_id: WidgetId) -> bool

Returns true if the widget was enabled in prev_target.

pub fn was_disabled(&self, widget_id: WidgetId) -> bool

Returns true if the widget was disabled in prev_target.

pub fn is_enabled(&self, widget_id: WidgetId) -> bool

Returns true if the widget is enabled in target.

pub fn is_disabled(&self, widget_id: WidgetId) -> bool

Returns true if the widget is disabled in target.

pub fn position_wgt(&self, wgt: (WindowId, WidgetId)) -> Option<PxPoint>

Gets position in the widget inner bounds.