pub struct MouseInputArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub device_id: Option<InputDeviceId>,
pub button: MouseButton,
pub position: DipPoint,
pub modifiers: ModifiersState,
pub state: ButtonState,
pub hits: HitTestInfo,
pub target: InteractionPath,
pub capture: Option<CaptureInfo>,
pub is_click: bool,
pub propagation: EventPropagationHandle,
}Expand description
MOUSE_INPUT_EVENT arguments.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdId of window that received the event.
device_id: Option<InputDeviceId>Id of device that generated the event.
Which mouse button generated the event.
position: DipPointPosition of the mouse in the window’s content area.
modifiers: ModifiersStateWhat modifier keys where pressed when this event happened.
state: ButtonStateThe state the button was changed to.
hits: HitTestInfoHit-test result for the mouse point in the window.
target: InteractionPathFull path to the top-most hit in hits.
capture: Option<CaptureInfo>Current pointer capture.
is_click: boolIf MOUSE_CLICK_EVENT will notify because of this input.
The click event shares the same propagation handle as this event.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl MouseInputArgs
impl MouseInputArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
window_id: impl Into<WindowId>,
device_id: impl Into<Option<InputDeviceId>>,
button: impl Into<MouseButton>,
position: impl Into<DipPoint>,
modifiers: impl Into<ModifiersState>,
state: impl Into<ButtonState>,
hits: impl Into<HitTestInfo>,
target: impl Into<InteractionPath>,
capture: impl Into<Option<CaptureInfo>>,
is_click: impl Into<bool>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, window_id: impl Into<WindowId>, device_id: impl Into<Option<InputDeviceId>>, button: impl Into<MouseButton>, position: impl Into<DipPoint>, modifiers: impl Into<ModifiersState>, state: impl Into<ButtonState>, hits: impl Into<HitTestInfo>, target: impl Into<InteractionPath>, capture: impl Into<Option<CaptureInfo>>, is_click: impl Into<bool>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(
window_id: impl Into<WindowId>,
device_id: impl Into<Option<InputDeviceId>>,
button: impl Into<MouseButton>,
position: impl Into<DipPoint>,
modifiers: impl Into<ModifiersState>,
state: impl Into<ButtonState>,
hits: impl Into<HitTestInfo>,
target: impl Into<InteractionPath>,
capture: impl Into<Option<CaptureInfo>>,
is_click: impl Into<bool>,
) -> Self
pub fn now( window_id: impl Into<WindowId>, device_id: impl Into<Option<InputDeviceId>>, button: impl Into<MouseButton>, position: impl Into<DipPoint>, modifiers: impl Into<ModifiersState>, state: impl Into<ButtonState>, hits: impl Into<HitTestInfo>, target: impl Into<InteractionPath>, capture: impl Into<Option<CaptureInfo>>, is_click: impl Into<bool>, ) -> Self
Arguments for event that happened now (INSTANT.now).
Sourceimpl MouseInputArgs
impl MouseInputArgs
Sourcepub fn capture_allows(&self, wgt: (WindowId, WidgetId)) -> bool
pub fn capture_allows(&self, wgt: (WindowId, WidgetId)) -> bool
Sourcepub fn is_primary(&self) -> bool
pub fn is_primary(&self) -> bool
If the button is the primary.
Sourcepub fn is_context(&self) -> bool
pub fn is_context(&self) -> bool
If the button is the context (right).
Sourcepub fn is_mouse_down(&self) -> bool
pub fn is_mouse_down(&self) -> bool
If the state is pressed.
Sourcepub fn is_mouse_up(&self) -> bool
pub fn is_mouse_up(&self) -> bool
If the state is released.