PointerCaptureArgs

Struct PointerCaptureArgs 

pub struct PointerCaptureArgs {
    pub timestamp: DInstant,
    pub prev_capture: Option<CaptureInfo>,
    pub new_capture: Option<CaptureInfo>,
    pub propagation: EventPropagationHandle,
}
Fields

timestamp: DInstant

Instant the event happened.

prev_capture: Option<CaptureInfo>

Previous mouse and touch capture target and mode.

new_capture: Option<CaptureInfo>

new mouse and capture target and mode.

propagation: EventPropagationHandle

Propagation handle associated with this event instance.

Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.

Implementations

Source

impl PointerCaptureArgs

pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, prev_capture: impl Into<Option<CaptureInfo>>, new_capture: impl Into<Option<CaptureInfo>>, ) -> Self

New args from values that convert into the argument types.

pub fn now( prev_capture: impl Into<Option<CaptureInfo>>, new_capture: impl Into<Option<CaptureInfo>>, ) -> Self

Arguments for event that happened now (INSTANT.now).

Source

impl PointerCaptureArgs

pub fn is_widget_move(&self) -> bool

If the same widget has pointer capture, but the widget path changed.

pub fn is_mode_change(&self) -> bool

If the same widget has pointer capture, but the capture mode changed.

pub fn is_lost(&self, widget_id: WidgetId) -> bool

If the widget_id lost pointer capture with this update.

pub fn is_got(&self, widget_id: WidgetId) -> bool

If the widget_id got pointer capture with this update.