pub struct TouchLongPressArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub device_id: InputDeviceId,
pub touch: TouchId,
pub position: DipPoint,
pub hits: HitTestInfo,
pub target: InteractionPath,
pub modifiers: ModifiersState,
pub start_time: DInstant,
pub propagation: EventPropagationHandle,
}Expand description
Arguments for TOUCH_LONG_PRESS_EVENT.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdId of window that received the event.
device_id: InputDeviceIdId of device that generated the event.
touch: TouchIdIdentify the touch contact or finger.
Multiple points of contact can happen in the same device at the same time, this ID identifies each uninterrupted contact. IDs are unique only among other concurrent touches on the same device, after a touch is ended an ID may be reused.
position: DipPointCenter of the touch in the window’s content area.
hits: HitTestInfoHit-test result for the touch point in the window.
target: InteractionPathFull path to the top-most hit in hits.
modifiers: ModifiersStateWhat modifier keys where pressed when this touch started.
start_time: DInstantTimestamp of when the touch started.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl TouchLongPressArgs
impl TouchLongPressArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
window_id: impl Into<WindowId>,
device_id: impl Into<InputDeviceId>,
touch: impl Into<TouchId>,
position: impl Into<DipPoint>,
hits: impl Into<HitTestInfo>,
target: impl Into<InteractionPath>,
modifiers: impl Into<ModifiersState>,
start_time: impl Into<DInstant>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, window_id: impl Into<WindowId>, device_id: impl Into<InputDeviceId>, touch: impl Into<TouchId>, position: impl Into<DipPoint>, hits: impl Into<HitTestInfo>, target: impl Into<InteractionPath>, modifiers: impl Into<ModifiersState>, start_time: impl Into<DInstant>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(
window_id: impl Into<WindowId>,
device_id: impl Into<InputDeviceId>,
touch: impl Into<TouchId>,
position: impl Into<DipPoint>,
hits: impl Into<HitTestInfo>,
target: impl Into<InteractionPath>,
modifiers: impl Into<ModifiersState>,
start_time: impl Into<DInstant>,
) -> Self
pub fn now( window_id: impl Into<WindowId>, device_id: impl Into<InputDeviceId>, touch: impl Into<TouchId>, position: impl Into<DipPoint>, hits: impl Into<HitTestInfo>, target: impl Into<InteractionPath>, modifiers: impl Into<ModifiersState>, start_time: impl Into<DInstant>, ) -> Self
Arguments for event that happened now (INSTANT.now).