TouchMoveArgs

Struct TouchMoveArgs 

pub struct TouchMoveArgs {
    pub timestamp: DInstant,
    pub window_id: WindowId,
    pub device_id: InputDeviceId,
    pub touches: Vec<TouchMove>,
    pub capture: Option<CaptureInfo>,
    pub modifiers: ModifiersState,
    pub propagation: EventPropagationHandle,
}
Arguments for TOUCH_MOVE_EVENT.

Fields

timestamp: DInstant

Instant the event happened.

window_id: WindowId

Id of window that received all touches in this event.

device_id: InputDeviceId

Id of device that generated all touches in this event.

touches: Vec<TouchMove>

All touch contacts that moved since last event.

Note that if a touch contact did not move it will not be in the list, the touch may still be active however, the TOUCH_INPUT_EVENT can be used to track touch start and end.

capture: Option<CaptureInfo>

Current pointer capture.

modifiers: ModifiersState

What modifier keys where pressed when this event happened.

propagation: EventPropagationHandle

Propagation handle associated with this event instance.

Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.

Implementations

Source

impl TouchMoveArgs

pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, window_id: impl Into<WindowId>, device_id: impl Into<InputDeviceId>, touches: impl Into<Vec<TouchMove>>, capture: impl Into<Option<CaptureInfo>>, modifiers: impl Into<ModifiersState>, ) -> Self

New args from values that convert into the argument types.

pub fn now( window_id: impl Into<WindowId>, device_id: impl Into<InputDeviceId>, touches: impl Into<Vec<TouchMove>>, capture: impl Into<Option<CaptureInfo>>, modifiers: impl Into<ModifiersState>, ) -> Self

Arguments for event that happened now (INSTANT.now).

Source

impl TouchMoveArgs

pub fn capture_allows(&self, wgt: (WindowId, WidgetId)) -> bool

If capture is None or allows the wgt to receive this event.