TouchedArgs

Struct TouchedArgs 

pub struct TouchedArgs {
Show 14 fields pub timestamp: DInstant, pub window_id: WindowId, pub device_id: Option<InputDeviceId>, pub touch: TouchId, pub touch_propagation: EventPropagationHandle, pub position: DipPoint, pub force: Option<TouchForce>, pub phase: TouchPhase, pub hits: HitTestInfo, pub prev_target: Option<InteractionPath>, pub target: Option<InteractionPath>, pub prev_capture: Option<CaptureInfo>, pub capture: Option<CaptureInfo>, pub propagation: EventPropagationHandle,
}
Arguments for TOUCHED_EVENT.

Fields

timestamp: DInstant

Instant the event happened.

window_id: WindowId

Id of window that received the event.

device_id: Option<InputDeviceId>

Id of device that generated the event.

touch: TouchId

Identify the touch contact or finger.

Multiple points of contact can happen in the same device at the same time, this ID identifies each uninterrupted contact. IDs are unique only among other concurrent touches on the same device, after a touch is ended an ID may be reused.

touch_propagation: EventPropagationHandle

Handle across the lifetime of touch.

See TouchInputArgs::touch_propagation for more details.

position: DipPoint

Center of the touch in the window’s content area.

force: Option<TouchForce>

Touch pressure force and angle.

phase: TouchPhase

Touch phase that caused the contact gain or loss with the widget.

hits: HitTestInfo

Hit-test result for the touch point in the window.

prev_target: Option<InteractionPath>

Previous top-most hit before the touch moved.

target: Option<InteractionPath>

Full path to the top-most hit in hits.

prev_capture: Option<CaptureInfo>

Previous pointer capture.

capture: Option<CaptureInfo>

Current pointer capture.

propagation: EventPropagationHandle

Propagation handle associated with this event instance.

Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.

Implementations

Source

impl TouchedArgs

pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, window_id: impl Into<WindowId>, device_id: impl Into<Option<InputDeviceId>>, touch: impl Into<TouchId>, touch_propagation: impl Into<EventPropagationHandle>, position: impl Into<DipPoint>, force: impl Into<Option<TouchForce>>, phase: impl Into<TouchPhase>, hits: impl Into<HitTestInfo>, prev_target: impl Into<Option<InteractionPath>>, target: impl Into<Option<InteractionPath>>, prev_capture: impl Into<Option<CaptureInfo>>, capture: impl Into<Option<CaptureInfo>>, ) -> Self

New args from values that convert into the argument types.

pub fn now( window_id: impl Into<WindowId>, device_id: impl Into<Option<InputDeviceId>>, touch: impl Into<TouchId>, touch_propagation: impl Into<EventPropagationHandle>, position: impl Into<DipPoint>, force: impl Into<Option<TouchForce>>, phase: impl Into<TouchPhase>, hits: impl Into<HitTestInfo>, prev_target: impl Into<Option<InteractionPath>>, target: impl Into<Option<InteractionPath>>, prev_capture: impl Into<Option<CaptureInfo>>, capture: impl Into<Option<CaptureInfo>>, ) -> Self

Arguments for event that happened now (INSTANT.now).

Source

impl TouchedArgs

pub fn capture_allows(&self, wgt: (WindowId, WidgetId)) -> bool

If capture is None or allows the wgt to receive this event.

pub fn is_touch_move(&self) -> bool

Event caused by the touch position moving over/out of the widget bounds.

pub fn is_widget_move(&self) -> bool

Event caused by the widget moving under/out of the mouse position.

pub fn is_capture_change(&self) -> bool

Event caused by a pointer capture change.

pub fn is_touch_enter(&self, wgt: (WindowId, WidgetId)) -> bool

Returns true if the wgt was not touched, but now is.

pub fn is_touch_leave(&self, wgt: (WindowId, WidgetId)) -> bool

Returns true if the wgt was touched, but now isn’t.

pub fn is_touch_enter_enabled(&self, wgt: (WindowId, WidgetId)) -> bool

Returns true if the wgt was not touched or was disabled, but now is touched and enabled.

pub fn is_touch_leave_enabled(&self, wgt: (WindowId, WidgetId)) -> bool

Returns true if the wgt was touched and enabled, but now is not touched or is disabled.

pub fn is_touch_enter_disabled(&self, wgt: (WindowId, WidgetId)) -> bool

Returns true if the wgt was not touched or was enabled, but now is touched and disabled.

pub fn is_touch_leave_disabled(&self, wgt: (WindowId, WidgetId)) -> bool

Returns true if the wgt was touched and disabled, but now is not touched or is enabled.

pub fn was_touched(&self, wgt: (WindowId, WidgetId)) -> bool

Returns true if the wgt is in prev_target and is allowed by the prev_capture.

pub fn is_touched(&self, wgt: (WindowId, WidgetId)) -> bool

Returns true if the wgt is in target and is allowed by the current capture.

pub fn was_enabled(&self, widget_id: WidgetId) -> bool

Returns true if the widget was enabled in prev_target.

pub fn was_disabled(&self, widget_id: WidgetId) -> bool

Returns true if the widget was disabled in prev_target.

pub fn is_enabled(&self, widget_id: WidgetId) -> bool

Returns true if the widget is enabled in target.

pub fn is_disabled(&self, widget_id: WidgetId) -> bool

Returns true if the widget is disabled in target.