pub struct MouseClickArgs {
pub timestamp: DInstant,
pub window_id: WindowId,
pub device_id: InputDeviceId,
pub button: MouseButton,
pub position: DipPoint,
pub modifiers: ModifiersState,
pub click_count: NonZeroU32,
pub is_repeat: bool,
pub hits: HitTestInfo,
pub target: InteractionPath,
pub propagation: EventPropagationHandle,
}Expand description
MOUSE_CLICK_EVENT arguments.
Fields
timestamp: DInstantInstant the event happened.
window_id: WindowIdId of window that received the event.
device_id: InputDeviceIdId of device that generated the event.
Which mouse button generated the event.
position: DipPointPosition of the mouse in the coordinates of target.
modifiers: ModifiersStateWhat modifier keys where pressed when this event happened.
click_count: NonZeroU32Count of clicks within the double-click interval. Number 1 is single click, 2 is double click, etc.
Auto repeated clicks also increment this count.
is_repeat: boolIf the event was generated by holding the button pressed over a widget with ClickMode::repeat.
hits: HitTestInfoHit-test result for the mouse point in the window, at the moment the click event was generated.
target: InteractionPathFull path to the widget that got clicked.
A widget is clicked if the mouse down and mouse up happen in sequence in the same widget. Subsequent clicks (double, triple) happen on mouse down.
If a mouse down happen in a child widget and the pointer is dragged to a larger parent widget and then let go (mouse up), the click target is the parent widget.
Multi-clicks (click_count > 1) only happen to the same target.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl MouseClickArgs
impl MouseClickArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
window_id: impl Into<WindowId>,
device_id: impl Into<InputDeviceId>,
button: impl Into<MouseButton>,
position: impl Into<DipPoint>,
modifiers: impl Into<ModifiersState>,
click_count: impl Into<NonZeroU32>,
is_repeat: impl Into<bool>,
hits: impl Into<HitTestInfo>,
target: impl Into<InteractionPath>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, window_id: impl Into<WindowId>, device_id: impl Into<InputDeviceId>, button: impl Into<MouseButton>, position: impl Into<DipPoint>, modifiers: impl Into<ModifiersState>, click_count: impl Into<NonZeroU32>, is_repeat: impl Into<bool>, hits: impl Into<HitTestInfo>, target: impl Into<InteractionPath>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(
window_id: impl Into<WindowId>,
device_id: impl Into<InputDeviceId>,
button: impl Into<MouseButton>,
position: impl Into<DipPoint>,
modifiers: impl Into<ModifiersState>,
click_count: impl Into<NonZeroU32>,
is_repeat: impl Into<bool>,
hits: impl Into<HitTestInfo>,
target: impl Into<InteractionPath>,
) -> Self
pub fn now( window_id: impl Into<WindowId>, device_id: impl Into<InputDeviceId>, button: impl Into<MouseButton>, position: impl Into<DipPoint>, modifiers: impl Into<ModifiersState>, click_count: impl Into<NonZeroU32>, is_repeat: impl Into<bool>, hits: impl Into<HitTestInfo>, target: impl Into<InteractionPath>, ) -> Self
Arguments for event that happened now (INSTANT.now).
Sourceimpl MouseClickArgs
impl MouseClickArgs
Sourcepub fn is_primary(&self) -> bool
pub fn is_primary(&self) -> bool
If the button is the primary.
Sourcepub fn is_context(&self) -> bool
pub fn is_context(&self) -> bool
If the button is the context (right).
Sourcepub fn is_single(&self) -> bool
pub fn is_single(&self) -> bool
If the click_count is 1.
Sourcepub fn is_double(&self) -> bool
pub fn is_double(&self) -> bool
If the click_count is 2.
Sourcepub fn is_triple(&self) -> bool
pub fn is_triple(&self) -> bool
If the click_count is 3.