pub struct PointerCaptureArgs {
pub timestamp: DInstant,
pub prev_capture: Option<CaptureInfo>,
pub new_capture: Option<CaptureInfo>,
pub propagation: EventPropagationHandle,
}Expand description
POINTER_CAPTURE_EVENT arguments.
Fields
timestamp: DInstantInstant the event happened.
prev_capture: Option<CaptureInfo>Previous mouse and touch capture target and mode.
new_capture: Option<CaptureInfo>new mouse and capture target and mode.
propagation: EventPropagationHandlePropagation handle associated with this event instance.
Cloned arguments share the same handle, some arguments may also share the handle of another event if they share the same cause.
Implementations
Sourceimpl PointerCaptureArgs
impl PointerCaptureArgs
Sourcepub fn new(
timestamp: impl Into<DInstant>,
propagation: EventPropagationHandle,
prev_capture: impl Into<Option<CaptureInfo>>,
new_capture: impl Into<Option<CaptureInfo>>,
) -> Self
pub fn new( timestamp: impl Into<DInstant>, propagation: EventPropagationHandle, prev_capture: impl Into<Option<CaptureInfo>>, new_capture: impl Into<Option<CaptureInfo>>, ) -> Self
New args from values that convert into the argument types.
Sourcepub fn now(
prev_capture: impl Into<Option<CaptureInfo>>,
new_capture: impl Into<Option<CaptureInfo>>,
) -> Self
pub fn now( prev_capture: impl Into<Option<CaptureInfo>>, new_capture: impl Into<Option<CaptureInfo>>, ) -> Self
Arguments for event that happened now (INSTANT.now).
Sourceimpl PointerCaptureArgs
impl PointerCaptureArgs
Sourcepub fn is_widget_move(&self) -> bool
pub fn is_widget_move(&self) -> bool
If the same widget has pointer capture, but the widget path changed.
Sourcepub fn is_mode_change(&self) -> bool
pub fn is_mode_change(&self) -> bool
If the same widget has pointer capture, but the capture mode changed.